;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ghub" "20251006.1821"
  "Client libraries for Git forge APIs."
  '((emacs  "29.1")
    (compat "30.1")
    (llama  "1.0")
    (treepy "0.1.2"))
  :url "https://github.com/magit/ghub"
  :commit "6dc4ff700fc515157131b2106a17bb667579d449"
  :revdesc "6dc4ff700fc5"
  :keywords '("tools")
  :authors '(("Jonas Bernoulli" . "emacs.ghub@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.ghub@jonas.bernoulli.dev")))
